@@ -1,10 +1,14 @@
 #!/bin/false
+# PODNAME: Net::Proxmox::VE
+# ABSTRACT: Pure perl API for Proxmox virtualisation
 
-package Net::Proxmox::VE;
-
-use Carp qw( croak );
 use strict;
 use warnings;
+
+package Net::Proxmox::VE;
+$Net::Proxmox::VE::VERSION = '0.0094';
+
+use Carp qw( croak );
 use HTTP::Headers;
 use HTTP::Request::Common qw(GET POST DELETE);
 use JSON qw(decode_json);
@@ -19,71 +23,6 @@ use Net::Proxmox::VE::Cluster;
 use Net::Proxmox::VE::Nodes;
 
 
-our $VERSION = 0.009;
-
-=encoding utf8
-
-=head1 NAME
-
-Net::Proxmox::VE - Pure perl API for Proxmox virtualisation
-
-=head1 SYNOPSIS
-
-    use Net::Proxmox::VE;
-
-    %args = (
-        host     => 'proxmox.local.domain',
-        password => 'barpassword',
-        username => 'root', # optional
-        port     => 8006,   # optional
-        realm    => 'pam',  # optional
-    );
-
-    $host = Net::Proxmox::VE->new(%args);
-
-    $host->login() or die ('Couldn\'t log in to proxmox host');
-
-=head1 WARNING
-
-We are still moving things around and trying to come up with something
-that makes sense. We havent yet implemented all the API functions,
-so far we only have a basic internal abstraction of the REST interface
-and a few modules for each function tree within the API.
-
-Any enchancements are greatly appreciated ! (use github, link below)
-
-Please dont be offended if we refactor and rework submissions.
-Perltidy with default settings is prefered style.
-
-Oh, our tests are all against a running server. Care to help make them better?
-
-=head1 DESIGN NOTE
-
-This API would be far nicer if it returned nice objects representing different aspects of the system.
-Such an arrangement would be far better than how this module is currently layed out. It might also be
-less repetitive code.
-
-=head1 DESCRIPTION
-
-This Class provides the framework for talking to Proxmox VE 2.0 API instances.
-This just provides a get/delete/put/post abstraction layer as methods on Proxmox VE REST API
-This also handles the ticket headers required for authentication
-
-More details on the API can be found here:
-http://pve.proxmox.com/wiki/Proxmox_VE_API
-http://pve.proxmox.com/pve2-api-doc/
-
-This class provides the building blocks for someone wanting to use PHP to talk to Proxmox 2.0. Relatively simple piece of code, just provides a get/put/post/delete abstraction layer as methods on top of Proxmox's REST API, while also handling the Login Ticket headers required for authentication.
-
-=head1 METHODS
-
-=head2 action
-
-This calls raw actions against your proxmox server.
-Ideally you don't use this directly.
-
-=cut
-
 sub action {
 
     my $self = shift or return;
@@ -159,7 +98,7 @@ sub action {
         print "DEBUG: successful request: " . $request->as_string . "\n"
           if $self->{params}->{debug};
 
-        my $content = $response->decoded_content;
+        # my $content = $response->decoded_content;
         my $data    = decode_json( $response->decoded_content );
 
         if ( ref $data eq 'HASH'
@@ -189,24 +128,12 @@ sub action {
 
 }
 
-=head2 api_version
-
-Returns the API version of the proxmox server we are talking to
-
-=cut
 
 sub api_version {
     my $self = shift or return;
     return $self->action( path => '/version', method => 'GET' );
 }
 
-=head2 api_version_check
-
-Checks that the api we are talking to is at least version 2.0
-
-Returns true if the api version is at least 2.0 (perl style true or false)
-
-=cut
 
 sub api_version_check {
     my $self = shift or return;
@@ -223,15 +150,6 @@ sub api_version_check {
     return;
 }
 
-=head2 debug
-
-Has a single optional argument of 1 or 0 representing enable or disable debugging.
-
-Undef (ie no argument) leaves the debug status untouched, making this method call simply a query.
-
-Returns the resultant debug status (perl style true or false)
-
-=cut
 
 sub debug {
     my $self = shift or return;
@@ -249,12 +167,6 @@ sub debug {
 
 }
 
-=head2 delete
-
-An action helper method that just takes a path as an argument and returns the
-value of action() with the DELETE method
-
-=cut
 
 sub delete {
     my $self = shift or return;
@@ -266,12 +178,6 @@ sub delete {
     return
 }
 
-=head2 get
-
-An action helper method that just takes a path as an argument and returns the
-value of action with the GET method
-
-=cut
 
 sub get {
     my $self = shift or return;
@@ -288,6 +194,206 @@ sub get {
     return;
 }
 
+
+sub new {
+
+    my $c     = shift;
+    my @p     = @_;
+    my $class = ref($c) || $c;
+
+    my %params;
+
+    if ( scalar @p == 1 ) {
+
+        croak 'new() requires a hash for params'
+          unless ref $p[0] eq 'HASH';
+
+        %params = %{ $p[0] };
+
+    }
+    elsif ( scalar @p % 2 != 0 ) {    # 'unless' is better than != but anyway
+        croak 'new() called with an odd number of parameters'
+
+    }
+    else {
+        %params = @p
+          or croak 'new() requires a hash for params';
+    }
+
+    croak 'host param is required'     unless $params{'host'};
+    croak 'password param is required' unless $params{'password'};
+
+    $params{port}     ||= 8006;
+    $params{username} ||= 'root';
+    $params{realm}    ||= 'pam';
+    $params{debug}    ||= undef;
+    $params{timeout}  ||= 10;
+
+    my $self->{params} = \%params;
+    $self->{'ticket'}           = undef;
+    $self->{'ticket_timestamp'} = undef;
+    $self->{'ticket_life'}      = 7200;    # 2 Hours
+
+    bless $self, $class;
+    return $self
+
+}
+
+
+sub post {
+
+    my $self      = shift or return;
+    my $post_data;
+    $post_data = pop
+        if ref $_[-1];
+    my @path = @_    or return;    # using || breaks this
+
+    if ( $self->nodes ) {
+
+        return $self->action(
+            path      => join( '/', @path ),
+            method    => 'POST',
+            post_data => $post_data
+          )
+
+    }
+    return
+}
+
+
+sub put {
+
+    my $self      = shift or return;
+    my $post_data;
+    $post_data = pop
+        if ref $_[-1];
+    my @path = @_    or return;    # using || breaks this
+
+    if ( $self->nodes ) {
+
+        return $self->action(
+            path      => join( '/', @path ),
+            method    => 'PUT',
+            post_data => $post_data
+          )
+
+    }
+    return
+}
+
+
+
+sub url_prefix {
+
+    my $self = shift or return;
+
+    # Prepare prefix for request
+    my $url_prefix = sprintf( 'https://%s:%s',
+        $self->{params}->{host},
+        $self->{params}->{port} );
+
+    return $url_prefix
+
+}
+
+
+1;
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Proxmox::VE - Pure perl API for Proxmox virtualisation
+
+=head1 VERSION
+
+version 0.0094
+
+=head1 SYNOPSIS
+
+    use Net::Proxmox::VE;
+
+    %args = (
+        host     => 'proxmox.local.domain',
+        password => 'barpassword',
+        username => 'root', # optional
+        port     => 8006,   # optional
+        realm    => 'pam',  # optional
+    );
+
+    $host = Net::Proxmox::VE->new(%args);
+
+    $host->login() or die ('Couldn\'t log in to proxmox host');
+
+=head1 DESCRIPTION
+
+This Class provides the framework for talking to Proxmox VE 2.0 API instances.
+This just provides a get/delete/put/post abstraction layer as methods on Proxmox VE REST API
+This also handles the ticket headers required for authentication
+
+More details on the API can be found here:
+http://pve.proxmox.com/wiki/Proxmox_VE_API
+http://pve.proxmox.com/pve2-api-doc/
+
+This class provides the building blocks for someone wanting to use PHP to talk to Proxmox 2.0. Relatively simple piece of code, just provides a get/put/post/delete abstraction layer as methods on top of Proxmox's REST API, while also handling the Login Ticket headers required for authentication.
+
+=head1 WARNING
+
+We are still moving things around and trying to come up with something
+that makes sense. We havent yet implemented all the API functions,
+so far we only have a basic internal abstraction of the REST interface
+and a few modules for each function tree within the API.
+
+Any enchancements are greatly appreciated ! (use github, link below)
+
+Please dont be offended if we refactor and rework submissions.
+Perltidy with default settings is prefered style.
+
+Oh, our tests are all against a running server. Care to help make them better?
+
+=head1 DESIGN NOTE
+
+This API would be far nicer if it returned nice objects representing different aspects of the system.
+Such an arrangement would be far better than how this module is currently layed out. It might also be
+less repetitive code.
+
+=head1 METHODS
+
+=head2 action
+
+This calls raw actions against your proxmox server.
+Ideally you don't use this directly.
+
+=head2 api_version
+
+Returns the API version of the proxmox server we are talking to
+
+=head2 api_version_check
+
+Checks that the api we are talking to is at least version 2.0
+
+Returns true if the api version is at least 2.0 (perl style true or false)
+
+=head2 debug
+
+Has a single optional argument of 1 or 0 representing enable or disable debugging.
+
+Undef (ie no argument) leaves the debug status untouched, making this method call simply a query.
+
+Returns the resultant debug status (perl style true or false)
+
+=head2 delete
+
+An action helper method that just takes a path as an argument and returns the
+value of action() with the DELETE method
+
+=head2 get
+
+An action helper method that just takes a path as an argument and returns the
+value of action with the GET method
+
 =head2 new
 
 Creates the Net::Proxmox::VE object and returns it.
@@ -349,52 +455,6 @@ Enabling debugging of this API (not related to proxmox debugging in any way). De
 
 =back
 
-=cut
-
-sub new {
-
-    my $c     = shift;
-    my @p     = @_;
-    my $class = ref($c) || $c;
-
-    my %params;
-
-    if ( scalar @p == 1 ) {
-
-        croak 'new() requires a hash for params'
-          unless ref $p[0] eq 'HASH';
-
-        %params = %{ $p[0] };
-
-    }
-    elsif ( scalar @p % 2 != 0 ) {    # 'unless' is better than != but anyway
-        croak 'new() called with an odd number of parameters'
-
-    }
-    else {
-        %params = @p
-          or croak 'new() requires a hash for params';
-    }
-
-    croak 'host param is required'     unless $params{'host'};
-    croak 'password param is required' unless $params{'password'};
-
-    $params{port}     ||= 8006;
-    $params{username} ||= 'root';
-    $params{realm}    ||= 'pam';
-    $params{debug}    ||= undef;
-    $params{timeout}  ||= 10;
-
-    my $self->{params} = \%params;
-    $self->{'ticket'}           = undef;
-    $self->{'ticket_timestamp'} = undef;
-    $self->{'ticket_life'}      = 7200;    # 2 Hours
-
-    bless $self, $class;
-    return $self
-
-}
-
 =head2 post
 
 An action helper method that takes two parameters: $path, \%post_data
@@ -402,28 +462,6 @@ $path to post to,  hash ref to %post_data
 
 You are returned what action() with the POST method returns
 
-=cut
-
-sub post {
-
-    my $self      = shift or return;
-    my $post_data;
-    $post_data = pop
-        if ref $_[-1];
-    my @path = @_    or return;    # using || breaks this
-
-    if ( $self->nodes ) {
-
-        return $self->action(
-            path      => join( '/', @path ),
-            method    => 'POST',
-            post_data => $post_data
-          )
-
-    }
-    return
-}
-
 =head2 put
 
 An action helper method that takes two parameters:
@@ -431,48 +469,10 @@ path
 hash ref to post data
 your returned what post returns
 
-=cut
-
-sub put {
-
-    my $self      = shift or return;
-    my $post_data;
-    $post_data = pop
-        if ref $_[-1];
-    my @path = @_    or return;    # using || breaks this
-
-    if ( $self->nodes ) {
-
-        return $self->action(
-            path      => join( '/', @path ),
-            method    => 'PUT',
-            post_data => $post_data
-          )
-
-    }
-    return
-}
-
-
 =head2 url_prefix
 
 returns the url prefix used in the rest api calls
 
-=cut
-
-sub url_prefix {
-
-    my $self = shift or return;
-
-    # Prepare prefix for request
-    my $url_prefix = sprintf( 'https://%s:%s',
-        $self->{params}->{host},
-        $self->{params}->{port} );
-
-    return $url_prefix
-
-}
-
 =head1 SEE ALSO
 
 =over 4
@@ -487,23 +487,19 @@ http://pve.proxmox.com/pve2-api-doc
 
 =back
 
-=head1 SUPPORT
+=head1 AUTHOR
 
- Contribute at http://github.com/mrproper/proxmox-ve-api-perl
+Brendan Beveridge <brendan@nodeintegration.com.au>, Dean Hamstead <dean@bytefoundry.com.au>
 
-=head1 LICENSE
- This program is free software; you can redistribute it and/or modify it under
- the same terms as Perl itself.
+=head1 COPYRIGHT AND LICENSE
 
-=head1 VERSION
+This software is copyright (c) 2016 by Dean Hamstad.
 
- 0.009
-
-=head1 AUTHORS
-
- Brendan Beveridge <brendan@nodeintegration.com.au>
- Dean Hamstead <dean@bytefoundry.com.au>
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1
+__END__
+
+# vim: softtabstop=2 tabstop=2 shiftwidth=2 ft=perl expandtab smarttab
