@@ -1,15 +1,17 @@
 #!/bin/false
-
-package Net::Proxmox::VE::Access;
+# PODNAME: Net::Proxmox::VE::Access
+# ABSTRACT: Functions for the 'access' portion of the API
 
 use strict;
 use warnings;
-use base 'Exporter';
+
+package Net::Proxmox::VE::Access;
+$Net::Proxmox::VE::Access::VERSION = '0.0094';
+use parent 'Exporter';
 
 use LWP::UserAgent;
 use JSON qw(decode_json);
 
-our $VERSION = 0.3;
 our @EXPORT =
   qw(
   access
@@ -23,12 +25,509 @@ our @EXPORT =
   update_access_password
   );
 
-=encoding utf8
+
+my $base = '/access';
+
+sub access {
+
+    my $self = shift or return;
+
+    return $self->get($base);
+
+}
+
+
+sub access_domains {
+
+    my $self = shift or return;
+
+    return $self->get( $base, 'domains' )
+
+}
+
+
+sub create_access_domains {
+
+    my $self = shift or return;
+    my @p = @_;
+
+    die 'No arguments for create_access_domains()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_access_domains()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_access_domains()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, 'domains', \%args )
+
+}
+
+
+sub get_access_domains {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No realm for get_access_domains()';
+    die 'realm must be a scalar for get_access_domains()' if ref $a;
+
+    return $self->get( $base, 'domains', $a )
+
+}
+
+
+sub update_access_domains {
+
+    my $self   = shift or return;
+    my $realm = shift or die 'No realm provided for update_access_domains()';
+    die 'realm must be a scalar for update_access_domains()' if ref $realm;
+    my @p = @_;
+
+    die 'No arguments for update_access_domains()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_access_domains()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_access_domains()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->put( $base, 'domains', $realm, \%args )
+
+}
+
+
+sub delete_access_domains {
+
+    my $self = shift or return;
+    my $a    = shift or die 'No argument given for delete_access_domains()';
+
+    return $self->delete( $base, 'domains', $a )
+
+}
+
+
+sub access_groups {
+
+    my $self = shift or return;
+
+    return $self->get( $base, 'groups' )
+
+}
+
+
+sub create_access_groups {
+
+    my $self = shift or return;
+    my @p = @_;
+
+    die 'No arguments for create_access_groups()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_access_groups()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_access_groups()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, 'groups', \%args )
+
+}
+
+
+sub get_access_groups {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No groupid for get_access_groups()';
+    die 'groupid must be a scalar for get_access_groups()' if ref $a;
+
+    return $self->get( $base, 'groups', $a )
+
+}
+
+
+sub update_access_groups {
+
+    my $self   = shift or return;
+    my $realm = shift or die 'No realm provided for update_access_groups()';
+    die 'realm must be a scalar for update_access_groups()' if ref $realm;
+    my @p = @_;
+
+    die 'No arguments for update_access_groups()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_access_groups()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_access_groups()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->put( $base, 'groups', $realm, \%args )
+
+}
+
+
+sub delete_access_groups {
+
+    my $self = shift or return;
+    my $a    = shift or die 'No argument given for delete_access_groups()';
+
+    return $self->delete( $base, 'groups', $a )
+
+}
+
+
+
+sub access_roles {
+
+    my $self = shift or return;
+
+    return $self->get( $base, 'roles' )
+
+}
+
+
+sub create_access_roles {
+
+    my $self = shift or return;
+    my @p = @_;
+
+    die 'No arguments for create_access_roles()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_access_roles()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_access_roles()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, 'roles', \%args )
+
+}
+
+
+sub get_access_roles {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No roleid for get_access_roles()';
+    die 'roleid must be a scalar for get_access_roles()' if ref $a;
+
+    return $self->get( $base, 'roles', $a )
+
+}
+
+
+sub update_access_roles {
+
+    my $self   = shift or return;
+    my $realm = shift or die 'No realm provided for update_access_roles()';
+    die 'realm must be a scalar for update_access_roles()' if ref $realm;
+    my @p = @_;
+
+    die 'No arguments for update_access_roles()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_access_roles()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_access_roles()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->put( $base, 'roles', $realm, \%args )
+
+}
+
+
+sub delete_access_roles {
+
+    my $self = shift or return;
+    my $a    = shift or die 'No argument given for delete_access_roles()';
+
+    return $self->delete( $base, 'roles', $a )
+
+}
+
+
+
+sub access_users {
+
+    my $self = shift or return;
+
+    return $self->get( $base, 'users' )
+
+}
+
+
+sub create_access_users {
+
+    my $self = shift or return;
+    my @p = @_;
+
+    die 'No arguments for create_access_users()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_access_users()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_access_users()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, 'users', \%args )
+
+}
+
+
+sub get_access_users {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No userid for get_access_users()';
+    die 'userid must be a scalar for get_access_users()' if ref $a;
+
+    return $self->get( $base, 'users', $a )
+
+}
+
+
+sub update_access_users {
+
+    my $self   = shift or return;
+    my $realm = shift or die 'No realm provided for update_access_users()';
+    die 'realm must be a scalar for update_access_users()' if ref $realm;
+    my @p = @_;
+
+    die 'No arguments for update_access_users()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_access_users()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_access_users()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->put( $base, 'users', $realm, \%args )
+
+}
+
+
+sub delete_access_users {
+
+    my $self = shift or return;
+    my $a    = shift or die 'No argument given for delete_access_users()';
+
+    return $self->delete( $base, 'users', $a )
+
+}
+
+
+sub check_login_ticket {
+
+    my $self = shift or return;
+
+    if (   $self->{ticket}
+        && ref $self->{ticket} eq 'HASH'
+        && $self->{ticket}
+        && $self->{ticket}->{ticket}
+        && $self->{ticket}->{CSRFPreventionToken}
+        && $self->{ticket}->{username} eq $self->{params}->{username} . '@'
+        . $self->{params}->{realm}
+        && $self->{ticket_timestamp}
+        && $self->{ticket_timestamp} < ( time() + $self->{ticket_life} ) )
+    {
+        return 1;
+    }
+    else {
+        $self->clear_login_ticket;
+    }
+
+    return
+
+}
+
+
+sub clear_login_ticket {
+
+    my $self = shift or return;
+
+    if ( $self->{ticket} or $self->{timestamp} ) {
+        $self->{ticket}           = undef;
+        $self->{ticket_timestamp} = undef;
+        return 1;
+    }
+
+    return
+
+}
+
+
+sub get_access_acl {
+
+    my $self = shift or return;
+
+    return $self->get( $base, 'acl' );
+
+}
+
+
+sub login {
+    my $self = shift or return;
+
+    # Prepare login request
+    my $url = $self->url_prefix . '/api2/json/access/ticket';
+
+    my %lwpUserAgentOptions;
+    if ($self->{params}->{ssl_opts}) {
+        $lwpUserAgentOptions{ssl_opts} = $self->{params}->{ssl_opts};
+    }
+
+    my $ua = LWP::UserAgent->new( %lwpUserAgentOptions );
+
+    $ua->timeout($self->{params}->{timeout});
+
+    $self->{ua} = $ua;
+
+    # Perform login request
+    my $request_time = time();
+    my $response     = $ua->post(
+        $url,
+        {
+            'username' => $self->{params}->{username} . '@'
+              . $self->{params}->{realm},
+            'password' => $self->{params}->{password},
+        },
+    );
+
+    if ( $response->is_success ) {
+        # my $content           = $response->decoded_content;
+        my $login_ticket_data = decode_json( $response->decoded_content );
+        $self->{ticket} = $login_ticket_data->{data};
+
+        # We use request time as the time to get the json ticket is undetermined,
+        # id rather have a ticket a few seconds shorter than have a ticket that incorrectly
+        # says its valid for a couple more
+        $self->{ticket_timestamp} = $request_time;
+        print "DEBUG: login successful\n"
+          if $self->{params}->{debug};
+        return 1;
+    }
+    else {
+
+        print "DEBUG: login not successful\n"
+          if $self->{params}->{debug};
+        print "DEBUG: " . $response->status_line . "\n"
+          if $self->{params}->{debug};
+
+    }
+
+    return;
+}
+
+
+sub update_access_acl {
+
+    my $self = shift or return;
+    my @p = @_;
+
+    die 'No arguments for update_acl()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_acl()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_acl()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->put( $base, 'acl', \%args )
+
+}
+
+
+sub update_access_password {
+
+    my $self = shift or return;
+    my @p = @_;
+
+    die 'No arguments for update_password()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_password()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_password()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->put( $base, 'password', \%args )
+
+}
+
+
+1;
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
 Net::Proxmox::VE::Access - Functions for the 'access' portion of the API
 
+=head1 VERSION
+
+version 0.0094
+
 =head1 SYNOPSIS
 
   # assuming $obj is a Net::Proxmox::VE object
@@ -46,18 +545,6 @@ Without arguments, returns the 'Directory index':
 
 Note: Accessible by all authententicated users.
 
-=cut
-
-my $base = '/access';
-
-sub access {
-
-    my $self = shift or return;
-
-    return $self->get($base);
-
-}
-
 =head2 access_domains
 
 Gets a list of access domains (aka the Authentication domain index)
@@ -68,16 +555,6 @@ Note: Anyone can access that, because we need that list for the login box (befor
 
 FIXME: currently this isn't implemented in this library.
 
-=cut
-
-sub access_domains {
-
-    my $self = shift or return;
-
-    return $self->get( $base, 'domains' )
-
-}
-
 =head2 create_access_domains
 
 Creates a new access domain
@@ -127,31 +604,6 @@ String. LDAP user attribute name. Optional.
 
 =back
 
-=cut
-
-sub create_access_domains {
-
-    my $self = shift or return;
-    my @p = @_;
-
-    die 'No arguments for create_access_domains()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_access_domains()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_access_domains()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, 'domains', \%args )
-
-}
-
 =head2 get_access_domains
 
 Gets a single access domain
@@ -160,19 +612,6 @@ Gets a single access domain
 
 realm is a string in pve-realm format
 
-=cut
-
-sub get_access_domains {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No realm for get_access_domains()';
-    die 'realm must be a scalar for get_access_domains()' if ref $a;
-
-    return $self->get( $base, 'domains', $a )
-
-}
-
 =head2 update_access_domains
 
 Updates (sets) a access domain's data
@@ -216,33 +655,6 @@ String. LDAP user attribute name. Optional.
 
 =back
 
-=cut
-
-sub update_access_domains {
-
-    my $self   = shift or return;
-    my $realm = shift or die 'No realm provided for update_access_domains()';
-    die 'realm must be a scalar for update_access_domains()' if ref $realm;
-    my @p = @_;
-
-    die 'No arguments for update_access_domains()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_access_domains()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_access_domains()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->put( $base, 'domains', $realm, \%args )
-
-}
-
 =head2 delete_access_domains
 
 Deletes a single access domain
@@ -251,17 +663,6 @@ Deletes a single access domain
 
 realm is a string in pve-realm format
 
-=cut
-
-sub delete_access_domains {
-
-    my $self = shift or return;
-    my $a    = shift or die 'No argument given for delete_access_domains()';
-
-    return $self->delete( $base, 'domains', $a )
-
-}
-
 =head2 access_groups
 
 Gets a list of access groups (aka the Group index)
@@ -270,16 +671,6 @@ Gets a list of access groups (aka the Group index)
 
 Note: The returned list is restricted to groups where you have 'User.Modify', 'Sys.Audit' or 'Group.Allocate' permissions on /access/groups/<<group>>.
 
-=cut
-
-sub access_groups {
-
-    my $self = shift or return;
-
-    return $self->get( $base, 'groups' )
-
-}
-
 =head2 create_access_groups
 
 Creates a new access group
@@ -301,31 +692,6 @@ String. This is a comment associated with the new group, this is optional.
 
 =back
 
-=cut
-
-sub create_access_groups {
-
-    my $self = shift or return;
-    my @p = @_;
-
-    die 'No arguments for create_access_groups()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_access_groups()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_access_groups()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, 'groups', \%args )
-
-}
-
 =head2 get_access_groups
 
 Gets a single access group
@@ -334,19 +700,6 @@ Gets a single access group
 
 groupid is a string in pve-groupid format
 
-=cut
-
-sub get_access_groups {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No groupid for get_access_groups()';
-    die 'groupid must be a scalar for get_access_groups()' if ref $a;
-
-    return $self->get( $base, 'groups', $a )
-
-}
-
 =head2 update_access_groups
 
 Updates (sets) a access group's data
@@ -366,33 +719,6 @@ String. This is a comment associated with the group, this is optional.
 
 =back
 
-=cut
-
-sub update_access_groups {
-
-    my $self   = shift or return;
-    my $realm = shift or die 'No realm provided for update_access_groups()';
-    die 'realm must be a scalar for update_access_groups()' if ref $realm;
-    my @p = @_;
-
-    die 'No arguments for update_access_groups()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_access_groups()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_access_groups()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->put( $base, 'groups', $realm, \%args )
-
-}
-
 =head2 delete_access_groups
 
 Deletes a single access group
@@ -401,18 +727,6 @@ Deletes a single access group
 
 groupid is a string in pve-groupid format
 
-=cut
-
-sub delete_access_groups {
-
-    my $self = shift or return;
-    my $a    = shift or die 'No argument given for delete_access_groups()';
-
-    return $self->delete( $base, 'groups', $a )
-
-}
-
-
 =head2 access_roles
 
 Gets a list of access roles (aka the Role index)
@@ -421,16 +735,6 @@ Gets a list of access roles (aka the Role index)
 
 Note: Accessible by all authententicated users.
 
-=cut
-
-sub access_roles {
-
-    my $self = shift or return;
-
-    return $self->get( $base, 'roles' )
-
-}
-
 =head2 create_access_roles
 
 Creates a new access role
@@ -452,31 +756,6 @@ String. A string in pve-string-list format. Optional.
 
 =back
 
-=cut
-
-sub create_access_roles {
-
-    my $self = shift or return;
-    my @p = @_;
-
-    die 'No arguments for create_access_roles()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_access_roles()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_access_roles()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, 'roles', \%args )
-
-}
-
 =head2 get_access_roles
 
 Gets a single access role
@@ -485,19 +764,6 @@ Gets a single access role
 
 roleid is a string in pve-roleid format
 
-=cut
-
-sub get_access_roles {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No roleid for get_access_roles()';
-    die 'roleid must be a scalar for get_access_roles()' if ref $a;
-
-    return $self->get( $base, 'roles', $a )
-
-}
-
 =head2 update_access_roles
 
 Updates (sets) a access role's data
@@ -521,33 +787,6 @@ Booelean. Append privileges to existing. Optional.
 
 =back
 
-=cut
-
-sub update_access_roles {
-
-    my $self   = shift or return;
-    my $realm = shift or die 'No realm provided for update_access_roles()';
-    die 'realm must be a scalar for update_access_roles()' if ref $realm;
-    my @p = @_;
-
-    die 'No arguments for update_access_roles()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_access_roles()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_access_roles()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->put( $base, 'roles', $realm, \%args )
-
-}
-
 =head2 delete_access_roles
 
 Deletes a single access role
@@ -556,18 +795,6 @@ Deletes a single access role
 
 roleid is a string in pve-roleid format
 
-=cut
-
-sub delete_access_roles {
-
-    my $self = shift or return;
-    my $a    = shift or die 'No argument given for delete_access_roles()';
-
-    return $self->delete( $base, 'roles', $a )
-
-}
-
-
 =head2 access_users
 
 Gets a list of users (aka the User index)
@@ -576,16 +803,6 @@ Gets a list of users (aka the User index)
 
 Note: You need 'Realm.AllocateUser' on '/access/realm/<<realm>>' on the realm of user <<userid>>, and 'User.Modify' permissions to '/access/groups/<<group>>' for any group specified (or 'User.Modify' on '/access/groups' if you pass no groups.
 
-=cut
-
-sub access_users {
-
-    my $self = shift or return;
-
-    return $self->get( $base, 'users' )
-
-}
-
 =head2 create_access_users
 
 Creates a new user
@@ -635,31 +852,6 @@ String. The users initial passowrd. Optional.
 
 =back
 
-=cut
-
-sub create_access_users {
-
-    my $self = shift or return;
-    my @p = @_;
-
-    die 'No arguments for create_access_users()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_access_users()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_access_users()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, 'users', \%args )
-
-}
-
 =head2 get_access_users
 
 Gets a single user
@@ -668,19 +860,6 @@ Gets a single user
 
 userid is a string in pve-userid format
 
-=cut
-
-sub get_access_users {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No userid for get_access_users()';
-    die 'userid must be a scalar for get_access_users()' if ref $a;
-
-    return $self->get( $base, 'users', $a )
-
-}
-
 =head2 update_access_users
 
 Updates (sets) a user's configuration
@@ -728,33 +907,6 @@ String. Optional.
 
 =back
 
-=cut
-
-sub update_access_users {
-
-    my $self   = shift or return;
-    my $realm = shift or die 'No realm provided for update_access_users()';
-    die 'realm must be a scalar for update_access_users()' if ref $realm;
-    my @p = @_;
-
-    die 'No arguments for update_access_users()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_access_users()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_access_users()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->put( $base, 'users', $realm, \%args )
-
-}
-
 =head2 delete_access_users
 
 Deletes a single user
@@ -763,17 +915,6 @@ Deletes a single user
 
 userid is a string in pve-userid format
 
-=cut
-
-sub delete_access_users {
-
-    my $self = shift or return;
-    my $a    = shift or die 'No argument given for delete_access_users()';
-
-    return $self->delete( $base, 'users', $a )
-
-}
-
 =head2 check_login_ticket
 
 Verifies if the objects login ticket is valid and not expired
@@ -781,52 +922,10 @@ Verifies if the objects login ticket is valid and not expired
 Returns true if valid
 Returns false and clears the the login ticket details inside the object if invalid
 
-=cut
-
-sub check_login_ticket {
-
-    my $self = shift or return;
-
-    if (   $self->{ticket}
-        && ref $self->{ticket} eq 'HASH'
-        && $self->{ticket}
-        && $self->{ticket}->{ticket}
-        && $self->{ticket}->{CSRFPreventionToken}
-        && $self->{ticket}->{username} eq $self->{params}->{username} . '@'
-        . $self->{params}->{realm}
-        && $self->{ticket_timestamp}
-        && $self->{ticket_timestamp} < ( time() + $self->{ticket_life} ) )
-    {
-        return 1;
-    }
-    else {
-        $self->clear_login_ticket;
-    }
-
-    return
-
-}
-
 =head2 clear_login_ticket
 
 Clears the login ticket inside the object
 
-=cut
-
-sub clear_login_ticket {
-
-    my $self = shift or return;
-
-    if ( $self->{ticket} or $self->{timestamp} ) {
-        $self->{ticket}           = undef;
-        $self->{ticket_timestamp} = undef;
-        return 1;
-    }
-
-    return
-
-}
-
 =head2 get_access_acl
 
 The returned list is restricted to objects where you have rights to modify permissions
@@ -835,77 +934,12 @@ The returned list is restricted to objects where you have rights to modify permi
 
 Note: The returned list is restricted to objects where you have rights to modify permissions.
 
-=cut
-
-sub get_access_acl {
-
-    my $self = shift or return;
-
-    return $self->get( $base, 'acl' );
-
-}
-
 =head2 login
 
 Initiates the log in to the PVE Server using JSON API, and potentially obtains an Access Ticket.
 
 Returns true if success
 
-=cut
-
-sub login {
-    my $self = shift or return;
-
-    # Prepare login request
-    my $url = $self->url_prefix . '/api2/json/access/ticket';
-
-    my %lwpUserAgentOptions;
-    if ($self->{params}->{ssl_opts}) {
-        $lwpUserAgentOptions{ssl_opts} = $self->{params}->{ssl_opts};
-    }
-
-    my $ua = LWP::UserAgent->new( %lwpUserAgentOptions );
-
-    $ua->timeout($self->{params}->{timeout});
-
-    $self->{ua} = $ua;
-
-    # Perform login request
-    my $request_time = time();
-    my $response     = $ua->post(
-        $url,
-        {
-            'username' => $self->{params}->{username} . '@'
-              . $self->{params}->{realm},
-            'password' => $self->{params}->{password},
-        },
-    );
-
-    if ( $response->is_success ) {
-        my $content           = $response->decoded_content;
-        my $login_ticket_data = decode_json( $response->decoded_content );
-        $self->{ticket} = $login_ticket_data->{data};
-
-        # We use request time as the time to get the json ticket is undetermined,
-        # id rather have a ticket a few seconds shorter than have a ticket that incorrectly
-        # says its valid for a couple more
-        $self->{ticket_timestamp} = $request_time;
-        print "DEBUG: login successful\n"
-          if $self->{params}->{debug};
-        return 1;
-    }
-    else {
-
-        print "DEBUG: login not successful\n"
-          if $self->{params}->{debug};
-        print "DEBUG: " . $response->status_line . "\n"
-          if $self->{params}->{debug};
-
-    }
-
-    return;
-}
-
 =head2 update_access_acl
 
 Updates (sets) an acl's data
@@ -943,31 +977,6 @@ String. List of users. Optional.
 
 =back
 
-=cut
-
-sub update_access_acl {
-
-    my $self = shift or return;
-    my @p = @_;
-
-    die 'No arguments for update_acl()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_acl()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_acl()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->put( $base, 'acl', \%args )
-
-}
-
 =head2 update_access_password
 
 Updates a users password
@@ -993,44 +1002,23 @@ String. User ID. Required.
 
 Note: Each user is allowed to change his own password. A user can change the password of another user if he has 'Realm.AllocateUser' (on the realm of user <<userid>>) and 'User.Modify' permission on /access/groups/<<group>> on a group where user <<userid>> is member of.
 
-=cut
-
-sub update_access_password {
-
-    my $self = shift or return;
-    my @p = @_;
-
-    die 'No arguments for update_password()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_password()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_password()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->put( $base, 'password', \%args )
-
-}
-
 =head1 SEE ALSO
 
   L<Net::Proxmox::VE>
 
-=head1 VERSION
+=head1 AUTHOR
 
-  VERSION 0.3
+Brendan Beveridge <brendan@nodeintegration.com.au>, Dean Hamstead <dean@bytefoundry.com.au>
 
-=head1 AUTHORS
+=head1 COPYRIGHT AND LICENSE
 
-  Brendan Beveridge L<<brendan@nodeintegration.com.au>>
-  Dean Hamstead L<<dean@bytefoundry.com.au>>
+This software is copyright (c) 2016 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1
+__END__
+
+# vim: softtabstop=2 tabstop=2 shiftwidth=2 ft=perl expandtab smarttab
