@@ -1,33 +1,16 @@
 #!/bin/false
-
-package Net::Proxmox::VE::Nodes;
+# PODNAME: Net::Proxmox::VE::Nodes
+# ABSTRACT: Functions for the 'nodes' portion of the API
 
 use strict;
 use warnings;
-use base 'Exporter';
 
-our $VERSION = 0.31;
+package Net::Proxmox::VE::Nodes;
+$Net::Proxmox::VE::Nodes::VERSION = '0.0094';
+use parent 'Exporter';
+
 our @EXPORT  = qw( nodes );
 
-=encoding utf8
-
-=head1 NAME
-
-Net::Proxmox::VE::Nodes - Functions for the 'nodes' portion of the API
-
-=head1 SYNOPSIS
-
-  # assuming $obj is a Net::Proxmox::VE object
-
-=head1 METHODS
-
-=head2 nodes
-
-Returns the 'Cluster node index'
-
-Note: Accessible by all authententicated users.
-
-=cut
 
 my $base = '/nodes';
 
@@ -39,17 +22,6 @@ sub nodes {
 
 }
 
-=head2 get_nodes
-
-Gets a single nodes details
-
-  $ok = $obj->get_nodes('node')
-
-node is a string in pve-node format
-
-Note: Accessible by all authententicated users.
-
-=cut
 
 sub get_nodes {
 
@@ -62,17 +34,6 @@ sub get_nodes {
 
 }
 
-=head2 get_nodes_aplinfo
-
-Gets a single nodes list of appliances
-
-  $ok = $obj->get_nodes_aplinfo('node')
-
-node is a string in pve-node format
-
-Note: Accessible by all authententicated users.
-
-=cut
 
 sub get_nodes_aplinfo {
 
@@ -85,31 +46,6 @@ sub get_nodes_aplinfo {
 
 }
 
-=head2 create_nodes_aplinfo
-
-Create (upload) appliance templates.
-
-  $ok = $obj->download_nodes_aplinfo('node',\%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item storage
-
-String. The storage to be used in pve-storage-id format. Required.
-
-=item template
-
-Data. The actual template. Required.
-
-=back
-
-Note: required permissions are ["perm","/storage/{storage}",["Datastore.AllocateTemplate"]]
-
-=cut
 
 sub create_nodes_aplinfo {
 
@@ -138,17 +74,6 @@ sub create_nodes_aplinfo {
 
 }
 
-=head2 get_nodes_dns
-
-Get DNS settings.
-
-  $ok = $obj->get_nodes_dns('node')
-
-node is a string in pve-node format
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
-
-=cut
 
 sub get_nodes_dns {
 
@@ -161,27 +86,6 @@ sub get_nodes_dns {
 
 }
 
-=head2 update_nodes_dns
-
-Updates (writes) DNS settings.
-
-  $ok = $obj->update_nodes_dns('node', \%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item search
-
-String. Search domain for host-name lookup. Required.
-
-=back
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
-
-=cut
 
 sub update_nodes_dns {
 
@@ -210,35 +114,6 @@ sub update_nodes_dns {
 
 }
 
-=head2 get_nodes_rrd
-
-Get nodes RRD statistics (returns PNG).
-
-  $ok = $obj->get_nodes_rrd('node', \%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item ds
-
-String. The list of datasources you wish to see, in pve-configid-list format. Required.
-
-=item timeframe
-
-Enum. Is either hour, day, week, month or year. Required.
-
-=item cf
-
-Enum. Is either AVERAGE or MAX. Controls the RRD consolidation function. Optional.
-
-=back
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
-
-=cut
 
 sub get_nodes_rrd {
 
@@ -267,31 +142,6 @@ sub get_nodes_rrd {
 
 }
 
-=head2 get_nodes_rrddata
-
-Get nodes RRD statistics.
-
-  $ok = $obj->get_nodes_rrddata('node', \%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item timeframe
-
-Enum. Is either hour, day, week, month or year. Required.
-
-=item cf
-
-Enum. Is either AVERAGE or MAX. Controls the RRD consolidation function. Optional.
-
-=back
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
-
-=cut
 
 sub get_nodes_rrddata {
 
@@ -320,17 +170,6 @@ sub get_nodes_rrddata {
 
 }
 
-=head2 get_nodes_status
-
-Gets node status
-
-  $ok = $obj->get_nodes_status('node')
-
-node is a string in pve-node format
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
-
-=cut
 
 sub get_nodes_status {
 
@@ -344,27 +183,6 @@ sub get_nodes_status {
 }
 
 
-=head2 update_nodes_status
-
-Reboot or shutdown a node
-
-  $ok = $obj->updates_nodes_status('node', \%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item command
-
-Enum. Either reboot or shutdown. Specifies the command. Required.
-
-=back
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.PowerMgmt"]]
-
-=cut
 
 sub update_nodes_status {
 
@@ -394,17 +212,6 @@ sub update_nodes_status {
 
 }
 
-=head2 get_nodes_subscription
-
-Read nodes subscription info
-
-  $ok = $obj->get_nodes_subscription('node')
-
-node is a string in pve-node format
-
-Note: Root only.
-
-=cut
 
 sub get_nodes_subscription {
 
@@ -417,27 +224,6 @@ sub get_nodes_subscription {
 
 }
 
-=head2 create_nodes_subscription
-
-Create/update nodes subscription info
-
-  $ok = $obj->create_nodes_subscription('node', \%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item force
-
-Boolean. Always connect to the server, even if we have up to date info inside local cache. Optional.
-
-=back
-
-Note: Root only.
-
-=cut
 
 sub create_nodes_subscription {
 
@@ -466,27 +252,6 @@ sub create_nodes_subscription {
 
 }
 
-=head2 update_nodes_subscription_key
-
-Updates/sets subscription key
-
-  $ok = $obj->update_nodes_subscription_key('node', \%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item key
-
-Boolean. Proxmox VE subscription key. Required.
-
-=back
-
-Note: Root only.
-
-=cut
 
 sub update_nodes_subscription_key {
 
@@ -515,17 +280,6 @@ sub update_nodes_subscription_key {
 
 }
 
-=head2 get_nodes_syslog
-
-Reads system log
-
-  $ok = $obj->get_nodes_syslog('node', \%args)
-
-node is a string in pve-node format
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Syslog"]]
-
-=cut
 
 sub get_nodes_syslog {
 
@@ -554,17 +308,6 @@ sub get_nodes_syslog {
 
 }
 
-=head2 get_nodes_time
-
-Read server time and time zone settings
-
-  $ok = $obj->get_nodes_time('node')
-
-node is a string in pve-node format
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
-
-=cut
 
 sub get_nodes_time {
 
@@ -577,27 +320,6 @@ sub get_nodes_time {
 
 }
 
-=head2 update_nodes_time
-
-Updates time zone
-
-  $ok = $obj->update_nodes_time('node', \%args)
-
-node is a string in pve-node format
-
-I<%args> may items contain from the following list
-
-=over 4
-
-=item timezone
-
-String. Time zone to be used, see '/usr/share/zoneinfo/zone.tab'. Required.
-
-=back
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Modify"]]
-
-=cut
 
 sub update_nodes_time {
 
@@ -626,17 +348,6 @@ sub update_nodes_time {
 
 }
 
-=head2 get_nodes_ubcfailcnt
-
-Get user_beancounters failcnt for all active containers.
-
-  $ok = $obj->get_nodes_ubcfailcnt('node')
-
-node is a string in pve-node format
-
-Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
-
-=cut
 
 sub get_nodes_ubcfailcnt {
 
@@ -649,17 +360,6 @@ sub get_nodes_ubcfailcnt {
 
 }
 
-=head2 get_nodes_version
-
-Get user_beancounters failcnt for all active containers.
-
-  $ok = $obj->get_nodes_version('node')
-
-node is a string in pve-node format
-
-Note: Accessible by all authententicated users.
-
-=cut
 
 sub get_nodes_version {
 
@@ -672,17 +372,6 @@ sub get_nodes_version {
 
 }
 
-=head2 create_nodes_vncshell
-
-Creates a VNC Shell proxy.
-
-  $ok = $obj->create_nodes_vncshell('node')
-
-node is a string in pve-node format
-
-Note: Restricted to users on realm 'pam'. Required permissions are ["perm","/nodes/{node}",["Sys.Console"]]
-
-=cut
 
 sub create_nodes_vncshell {
 
@@ -695,6 +384,673 @@ sub create_nodes_vncshell {
 
 }
 
+
+sub create_nodes_vzdump {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for create_nodes_vzdump()';
+    die 'node must be a scalar for create_nodes_vzdump()' if ref $a;
+
+    my @p = @_;
+
+    die 'No arguments for create_nodes_vzdump()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_nodes_vzdump()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_nodes_vzdump()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, $a, 'dns', \%args )
+
+}
+
+
+sub nodes_network {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for nodes_network()';
+    die 'node must be a scalar for nodes_network()' if ref $a;
+
+    my @p = @_;
+
+    die 'No arguments for nodes_network()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for nodes_network()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for nodes_network()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->get( $base, $a, 'network', \%args )
+
+}
+
+
+sub create_nodes_network {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for create_nodes_network()';
+    die 'node must be a scalar for create_nodes_network()' if ref $a;
+
+    my @p = @_;
+
+    die 'No arguments for create_nodes_network()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_nodes_network()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_nodes_network()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, $a, 'network', \%args )
+
+}
+
+
+sub revert_nodes_network {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for revert_nodes_network()';
+    die 'node must be a scalar for revert_nodes_network()' if ref $a;
+
+    return $self->delete( $base, $a )
+
+}
+
+
+
+sub get_nodes_network_iface {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for get_nodes_network_iface()';
+    my $b = shift or die 'No iface for get_nodes_network_iface()';
+
+    die 'node must be a scalar for get_nodes_network_iface()' if ref $a;
+    die 'iface must be a scalar for get_nodes_network_iface()' if ref $b;
+
+    return $self->get( $base, $a, 'network', $b )
+
+}
+
+
+sub update_nodes_network_iface {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for update_nodes_network_iface()';
+    my $b = shift or die 'No iface for update_nodes_network_iface()';
+
+    die 'node must be a scalar for update_nodes_network_iface()' if ref $a;
+    die 'iface must be a scalar for update_nodes_network_iface()' if ref $b;
+
+    my @p = @_;
+
+    die 'No arguments for update_nodes_network_iface()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_nodes_network_iface()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_nodes_network_iface()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, $a, 'network', $b, \%args )
+
+}
+
+
+sub delete_nodes_network_iface {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for delete_nodes_network_iface()';
+    my $b = shift or die 'No iface for delete_nodes_network_iface()';
+
+    die 'node must be a scalar for delete_nodes_network_iface()' if ref $a;
+    die 'iface must be a scalar for delete_nodes_network_iface()' if ref $b;
+
+    return $self->get( $base, $a, 'network', $b )
+
+}
+
+
+sub nodes_openvz {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for nodes_openvz()';
+    die 'node must be a scalar for nodes_openvz()' if ref $a;
+
+    return $self->get( $base, $a, 'openvz')
+
+}
+
+
+sub create_nodes_openvz {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for create_nodes_openvz()';
+    die 'node must be a scalar for create_nodes_openvz()' if ref $a;
+
+    my @p = @_;
+
+    die 'No arguments for create_nodes_openvz()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_nodes_openvz()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_nodes_openvz()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->get( $base, $a, 'openvz', \%args )
+
+}
+
+
+sub get_nodes_openvz {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for get_nodes_openvz()';
+    die 'node must be a scalar for get_nodes_openvz()' if ref $a;
+
+    my $b = shift or die 'No node for get_nodes_openvz()';
+    die 'node must be a scalar for get_nodes_openvz()' if ref $b;
+
+    return $self->get( $base, $a, 'openvz', $b )
+
+}
+
+
+sub delete_nodes_openvz {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for delete_nodes_openvz()';
+    die 'node must be a scalar for delete_nodes_openvz()' if ref $a;
+
+    my $b = shift or die 'No node for delete_nodes_openvz()';
+    die 'node must be a scalar for delete_nodes_openvz()' if ref $b;
+
+    return $self->delete( $base, $a, 'openvz', $b )
+
+}
+
+
+sub get_nodes_openvz_status {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for get_nodes_openvz_status()';
+    die 'node must be a scalar for get_nodes_openvz_status()' if ref $a;
+
+    my $b = shift or die 'No node for get_nodes_openvz_status()';
+    die 'node must be a scalar for get_nodes_openvz_status()' if ref $b;
+
+    return $self->get( $base, $a, 'openvz', $b, 'status' )
+
+}
+
+
+sub get_nodes_openvz_status_current {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for get_nodes_openvz_status_current()';
+    die 'node must be a scalar for get_nodes_openvz_status_current()' if ref $a;
+
+    my $b = shift or die 'No node for get_nodes_openvz_status_current()';
+    die 'node must be a scalar for get_nodes_openvz_status_current()' if ref $b;
+
+    return $self->get( $base, $a, 'openvz', $b, 'status', 'current' )
+
+}
+
+
+sub create_nodes_openvz_status_mount {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for create_nodes_openvz_status_mount()';
+    die 'node must be a scalar for create_nodes_openvz_status_mount()' if ref $a;
+
+    my $b = shift or die 'No node for create_nodes_openvz_status_mount()';
+    die 'node must be a scalar for create_nodes_openvz_status_mount()' if ref $b;
+
+    return $self->post( $base, $a, 'openvz', $b, 'status', 'mount' )
+
+}
+
+
+sub create_nodes_openvz_status_shutdown {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for create_nodes_openvz_status_shutdown()';
+    die 'node must be a scalar for create_nodes_openvz_status_shutdown()' if ref $a;
+
+    my $b = shift or die 'No node for create_nodes_openvz_status_shutdown()';
+    die 'node must be a scalar for create_nodes_openvz_status_shutdown()' if ref $b;
+
+    my @p = @_;
+
+    die 'No arguments for create_nodes_openvz_status_shutdown()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_nodes_openvz_status_shutdown()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_nodes_openvz_status_shutdown()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, $a, 'openvz', $b, 'status', 'shutdown', \%args )
+
+}
+
+
+sub create_nodes_openvz_status_start {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for create_nodes_openvz_status_start()';
+    die 'node must be a scalar for create_nodes_openvz_status_start()' if ref $a;
+
+    my $b = shift or die 'No node for create_nodes_openvz_status_start()';
+    die 'node must be a scalar for create_nodes_openvz_status_start()' if ref $b;
+
+    return $self->post( $base, $a, 'openvz', $b, 'status', 'start' )
+
+}
+
+
+sub create_nodes_openvz_status_stop {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for create_nodes_openvz_status_stop()';
+    die 'node must be a scalar for create_nodes_openvz_status_stop()' if ref $a;
+
+    my $b = shift or die 'No node for create_nodes_openvz_status_stop()';
+    die 'node must be a scalar for create_nodes_openvz_status_stop()' if ref $b;
+
+    return $self->post( $base, $a, 'openvz', $b, 'status', 'start' )
+
+}
+
+
+sub get_nodes_openvz_status_ubc {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for get_nodes_openvz_status_ubc()';
+    die 'node must be a scalar for get_nodes_openvz_status_ubc()' if ref $a;
+
+    my $b = shift or die 'No node for get_nodes_openvz_status_ubc()';
+    die 'node must be a scalar for get_nodes_openvz_status_ubc()' if ref $b;
+
+    return $self->post( $base, $a, 'openvz', $b, 'status', 'ubc' )
+
+}
+
+
+sub get_nodes_openvz_status_umount {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No node for get_nodes_openvz_status_umount()';
+    die 'node must be a scalar for get_nodes_openvz_status_umount()' if ref $a;
+
+    my $b = shift or die 'No node for get_nodes_openvz_status_umount()';
+    die 'node must be a scalar for get_nodes_openvz_status_umount()' if ref $b;
+
+    return $self->post( $base, $a, 'openvz', $b, 'status', 'umount' )
+
+}
+
+
+1;
+
+=pod
+
+=encoding UTF-8
+
+=head1 NAME
+
+Net::Proxmox::VE::Nodes - Functions for the 'nodes' portion of the API
+
+=head1 VERSION
+
+version 0.0094
+
+=head1 SYNOPSIS
+
+  # assuming $obj is a Net::Proxmox::VE object
+
+=head1 METHODS
+
+=head2 nodes
+
+Returns the 'Cluster node index'
+
+Note: Accessible by all authententicated users.
+
+=head2 get_nodes
+
+Gets a single nodes details
+
+  $ok = $obj->get_nodes('node')
+
+node is a string in pve-node format
+
+Note: Accessible by all authententicated users.
+
+=head2 get_nodes_aplinfo
+
+Gets a single nodes list of appliances
+
+  $ok = $obj->get_nodes_aplinfo('node')
+
+node is a string in pve-node format
+
+Note: Accessible by all authententicated users.
+
+=head2 create_nodes_aplinfo
+
+Create (upload) appliance templates.
+
+  $ok = $obj->download_nodes_aplinfo('node',\%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item storage
+
+String. The storage to be used in pve-storage-id format. Required.
+
+=item template
+
+Data. The actual template. Required.
+
+=back
+
+Note: required permissions are ["perm","/storage/{storage}",["Datastore.AllocateTemplate"]]
+
+=head2 get_nodes_dns
+
+Get DNS settings.
+
+  $ok = $obj->get_nodes_dns('node')
+
+node is a string in pve-node format
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
+
+=head2 update_nodes_dns
+
+Updates (writes) DNS settings.
+
+  $ok = $obj->update_nodes_dns('node', \%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item search
+
+String. Search domain for host-name lookup. Required.
+
+=back
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
+
+=head2 get_nodes_rrd
+
+Get nodes RRD statistics (returns PNG).
+
+  $ok = $obj->get_nodes_rrd('node', \%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item ds
+
+String. The list of datasources you wish to see, in pve-configid-list format. Required.
+
+=item timeframe
+
+Enum. Is either hour, day, week, month or year. Required.
+
+=item cf
+
+Enum. Is either AVERAGE or MAX. Controls the RRD consolidation function. Optional.
+
+=back
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
+
+=head2 get_nodes_rrddata
+
+Get nodes RRD statistics.
+
+  $ok = $obj->get_nodes_rrddata('node', \%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item timeframe
+
+Enum. Is either hour, day, week, month or year. Required.
+
+=item cf
+
+Enum. Is either AVERAGE or MAX. Controls the RRD consolidation function. Optional.
+
+=back
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
+
+=head2 get_nodes_status
+
+Gets node status
+
+  $ok = $obj->get_nodes_status('node')
+
+node is a string in pve-node format
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
+
+=head2 update_nodes_status
+
+Reboot or shutdown a node
+
+  $ok = $obj->updates_nodes_status('node', \%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item command
+
+Enum. Either reboot or shutdown. Specifies the command. Required.
+
+=back
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.PowerMgmt"]]
+
+=head2 get_nodes_subscription
+
+Read nodes subscription info
+
+  $ok = $obj->get_nodes_subscription('node')
+
+node is a string in pve-node format
+
+Note: Root only.
+
+=head2 create_nodes_subscription
+
+Create/update nodes subscription info
+
+  $ok = $obj->create_nodes_subscription('node', \%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item force
+
+Boolean. Always connect to the server, even if we have up to date info inside local cache. Optional.
+
+=back
+
+Note: Root only.
+
+=head2 update_nodes_subscription_key
+
+Updates/sets subscription key
+
+  $ok = $obj->update_nodes_subscription_key('node', \%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item key
+
+Boolean. Proxmox VE subscription key. Required.
+
+=back
+
+Note: Root only.
+
+=head2 get_nodes_syslog
+
+Reads system log
+
+  $ok = $obj->get_nodes_syslog('node', \%args)
+
+node is a string in pve-node format
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Syslog"]]
+
+=head2 get_nodes_time
+
+Read server time and time zone settings
+
+  $ok = $obj->get_nodes_time('node')
+
+node is a string in pve-node format
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
+
+=head2 update_nodes_time
+
+Updates time zone
+
+  $ok = $obj->update_nodes_time('node', \%args)
+
+node is a string in pve-node format
+
+I<%args> may items contain from the following list
+
+=over 4
+
+=item timezone
+
+String. Time zone to be used, see '/usr/share/zoneinfo/zone.tab'. Required.
+
+=back
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Modify"]]
+
+=head2 get_nodes_ubcfailcnt
+
+Get user_beancounters failcnt for all active containers.
+
+  $ok = $obj->get_nodes_ubcfailcnt('node')
+
+node is a string in pve-node format
+
+Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
+
+=head2 get_nodes_version
+
+Get user_beancounters failcnt for all active containers.
+
+  $ok = $obj->get_nodes_version('node')
+
+node is a string in pve-node format
+
+Note: Accessible by all authententicated users.
+
+=head2 create_nodes_vncshell
+
+Creates a VNC Shell proxy.
+
+  $ok = $obj->create_nodes_vncshell('node')
+
+node is a string in pve-node format
+
+Note: Restricted to users on realm 'pam'. Required permissions are ["perm","/nodes/{node}",["Sys.Console"]]
+
 =head2 create_nodes_vzdump
 
 Create backup.
@@ -795,35 +1151,6 @@ String. The ID of the VM you want to backup in pve-vm-list format. Optional.
 
 Note: The user needs 'VM.Backup' permissions on any VM, and 'Datastore.AllocateSpace' on the backup storage.
 
-=cut
-
-sub create_nodes_vzdump {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for create_nodes_vzdump()';
-    die 'node must be a scalar for create_nodes_vzdump()' if ref $a;
-
-    my @p = @_;
-
-    die 'No arguments for create_nodes_vzdump()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_nodes_vzdump()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_nodes_vzdump()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, $a, 'dns', \%args )
-
-}
-
 =head2 nodes_network
 
 List available networks on the node
@@ -844,35 +1171,6 @@ Enum. One of bond, bridge, alias or eth. Only list specific interface types. Opt
 
 Note: Accessible by all authententicated users.
 
-=cut
-
-sub nodes_network {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for nodes_network()';
-    die 'node must be a scalar for nodes_network()' if ref $a;
-
-    my @p = @_;
-
-    die 'No arguments for nodes_network()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for nodes_network()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for nodes_network()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->get( $base, $a, 'network', \%args )
-
-}
-
 =head2 create_nodes_network
 
 Create network device configuration
@@ -921,35 +1219,6 @@ String. Specify the interfaces used by the bonding device in pve-iface-list form
 
 Note: required permissions are ["perm","/nodes/{node}",["Sys.Modify"]]
 
-=cut
-
-sub create_nodes_network {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for create_nodes_network()';
-    die 'node must be a scalar for create_nodes_network()' if ref $a;
-
-    my @p = @_;
-
-    die 'No arguments for create_nodes_network()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_nodes_network()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_nodes_network()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, $a, 'network', \%args )
-
-}
-
 =head2 revert_nodes_network
 
 Revert network configuration changes.
@@ -960,20 +1229,6 @@ node is a string in pve-node format
 
 Note: required permissions are ["perm","/nodes/{node}",["Sys.Modify"]]
 
-=cut
-
-sub revert_nodes_network {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for revert_nodes_network()';
-    die 'node must be a scalar for revert_nodes_network()' if ref $a;
-
-    return $self->delete( $base, $a )
-
-}
-
-
 =head2 get_nodes_network_iface
 
 Read network device configuration
@@ -984,22 +1239,6 @@ node is a string in pve-node format, iface is a string in pve-iface format
 
 Note: required permissions are ["perm","/nodes/{node}",["Sys.Audit"]]
 
-=cut
-
-sub get_nodes_network_iface {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for get_nodes_network_iface()';
-    my $b = shift or die 'No iface for get_nodes_network_iface()';
-
-    die 'node must be a scalar for get_nodes_network_iface()' if ref $a;
-    die 'iface must be a scalar for get_nodes_network_iface()' if ref $b;
-
-    return $self->get( $base, $a, 'network', $b )
-
-}
-
 =head2 update_nodes_network_iface
 
 Create network device configuration
@@ -1048,38 +1287,6 @@ String. Specify the interfaces used by the bonding device in pve-iface-list form
 
 Note: required permissions are ["perm","/nodes/{node}",["Sys.Modify"]]
 
-=cut
-
-sub update_nodes_network_iface {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for update_nodes_network_iface()';
-    my $b = shift or die 'No iface for update_nodes_network_iface()';
-
-    die 'node must be a scalar for update_nodes_network_iface()' if ref $a;
-    die 'iface must be a scalar for update_nodes_network_iface()' if ref $b;
-
-    my @p = @_;
-
-    die 'No arguments for update_nodes_network_iface()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_nodes_network_iface()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_nodes_network_iface()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, $a, 'network', $b, \%args )
-
-}
-
 =head2 delete_nodes_network_iface
 
 Delete network device configuration
@@ -1090,22 +1297,6 @@ node is a string in pve-node format, iface is a string in pve-iface format
 
 Note: required permissions are ["perm","/nodes/{node}",["Sys.Modify"]]
 
-=cut
-
-sub delete_nodes_network_iface {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for delete_nodes_network_iface()';
-    my $b = shift or die 'No iface for delete_nodes_network_iface()';
-
-    die 'node must be a scalar for delete_nodes_network_iface()' if ref $a;
-    die 'iface must be a scalar for delete_nodes_network_iface()' if ref $b;
-
-    return $self->get( $base, $a, 'network', $b )
-
-}
-
 =head2 nodes_openvz
 
 OpenVZ container index (per node).
@@ -1116,19 +1307,6 @@ node is a string in pve-node format
 
 Note: Only lists VMs where you have VM.Audit permissons on /vms/<vmid>.
 
-=cut
-
-sub nodes_openvz {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for nodes_openvz()';
-    die 'node must be a scalar for nodes_openvz()' if ref $a;
-
-    return $self->get( $base, $a, 'openvz')
-
-}
-
 =head2 create_nodes_openvz
 
 Create or restore a container.
@@ -1231,35 +1409,6 @@ Note: You need 'VM.Allocate' permissions on /vms/{vmid} or on the VM pool /pool/
 
 required permissions are ["or",["perm","/vms/{vmid}",["VM.Allocate"]],["perm","/pool/{pool}",["VM.Allocate"],"require_param","pool"]]
 
-=cut
-
-sub create_nodes_openvz {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for create_nodes_openvz()';
-    die 'node must be a scalar for create_nodes_openvz()' if ref $a;
-
-    my @p = @_;
-
-    die 'No arguments for create_nodes_openvz()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_nodes_openvz()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_nodes_openvz()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->get( $base, $a, 'openvz', \%args )
-
-}
-
 =head2 get_nodes_openvz
 
 Gets an openvz nodes details
@@ -1272,22 +1421,6 @@ mvid is an integer in pve-vmid format
 
 Note: Accessible by all authententicated users.
 
-=cut
-
-sub get_nodes_openvz {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for get_nodes_openvz()';
-    die 'node must be a scalar for get_nodes_openvz()' if ref $a;
-
-    my $b = shift or die 'No node for get_nodes_openvz()';
-    die 'node must be a scalar for get_nodes_openvz()' if ref $b;
-
-    return $self->get( $base, $a, 'openvz', $b )
-
-}
-
 =head2 delete_nodes_openvz
 
 Destroy the container (also delete all uses files).
@@ -1300,22 +1433,6 @@ mvid is an integer in pve-vmid format
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.Allocate"]]
 
-=cut
-
-sub delete_nodes_openvz {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for delete_nodes_openvz()';
-    die 'node must be a scalar for delete_nodes_openvz()' if ref $a;
-
-    my $b = shift or die 'No node for delete_nodes_openvz()';
-    die 'node must be a scalar for delete_nodes_openvz()' if ref $b;
-
-    return $self->delete( $base, $a, 'openvz', $b )
-
-}
-
 =head2 get_nodes_openvz_status
 
 Directory index
@@ -1328,22 +1445,6 @@ mvid is an integer in pve-vmid format
 
 Note: Accessible by all authententicated users.
 
-=cut
-
-sub get_nodes_openvz_status {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for get_nodes_openvz_status()';
-    die 'node must be a scalar for get_nodes_openvz_status()' if ref $a;
-
-    my $b = shift or die 'No node for get_nodes_openvz_status()';
-    die 'node must be a scalar for get_nodes_openvz_status()' if ref $b;
-
-    return $self->get( $base, $a, 'openvz', $b, 'status' )
-
-}
-
 =head2 get_nodes_openvz_status_current
 
 Get virtual machine status.
@@ -1356,22 +1457,6 @@ mvid is an integer in pve-vmid format
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.Audit"]]
 
-=cut
-
-sub get_nodes_openvz_status_current {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for get_nodes_openvz_status_current()';
-    die 'node must be a scalar for get_nodes_openvz_status_current()' if ref $a;
-
-    my $b = shift or die 'No node for get_nodes_openvz_status_current()';
-    die 'node must be a scalar for get_nodes_openvz_status_current()' if ref $b;
-
-    return $self->get( $base, $a, 'openvz', $b, 'status', 'current' )
-
-}
-
 =head2 create_nodes_openvz_status_mount
 
 Mounts container private area.
@@ -1384,22 +1469,6 @@ mvid is an integer in pve-vmid format
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.PowerMgmt"]]
 
-=cut
-
-sub create_nodes_openvz_status_mount {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for create_nodes_openvz_status_mount()';
-    die 'node must be a scalar for create_nodes_openvz_status_mount()' if ref $a;
-
-    my $b = shift or die 'No node for create_nodes_openvz_status_mount()';
-    die 'node must be a scalar for create_nodes_openvz_status_mount()' if ref $b;
-
-    return $self->post( $base, $a, 'openvz', $b, 'status', 'mount' )
-
-}
-
 =head2 create_nodes_openvz_status_shutdown
 
 Shutdown the container.
@@ -1426,38 +1495,6 @@ Integer. Wait maximal timeout seconds
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.PowerMgmt"]]
 
-=cut
-
-sub create_nodes_openvz_status_shutdown {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for create_nodes_openvz_status_shutdown()';
-    die 'node must be a scalar for create_nodes_openvz_status_shutdown()' if ref $a;
-
-    my $b = shift or die 'No node for create_nodes_openvz_status_shutdown()';
-    die 'node must be a scalar for create_nodes_openvz_status_shutdown()' if ref $b;
-
-    my @p = @_;
-
-    die 'No arguments for create_nodes_openvz_status_shutdown()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_nodes_openvz_status_shutdown()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_nodes_openvz_status_shutdown()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, $a, 'openvz', $b, 'status', 'shutdown', \%args )
-
-}
-
 =head2 create_nodes_openvz_status_start
 
 Start the container.
@@ -1470,22 +1507,6 @@ vmid is an integer in pve-vmid format
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.PowerMgmt"]]
 
-=cut
-
-sub create_nodes_openvz_status_start {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for create_nodes_openvz_status_start()';
-    die 'node must be a scalar for create_nodes_openvz_status_start()' if ref $a;
-
-    my $b = shift or die 'No node for create_nodes_openvz_status_start()';
-    die 'node must be a scalar for create_nodes_openvz_status_start()' if ref $b;
-
-    return $self->post( $base, $a, 'openvz', $b, 'status', 'start' )
-
-}
-
 =head2 create_nodes_openvz_status_stop
 
 Stop the container.
@@ -1498,22 +1519,6 @@ vmid is an integer in pve-vmid format
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.PowerMgmt"]]
 
-=cut
-
-sub create_nodes_openvz_status_stop {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for create_nodes_openvz_status_stop()';
-    die 'node must be a scalar for create_nodes_openvz_status_stop()' if ref $a;
-
-    my $b = shift or die 'No node for create_nodes_openvz_status_stop()';
-    die 'node must be a scalar for create_nodes_openvz_status_stop()' if ref $b;
-
-    return $self->post( $base, $a, 'openvz', $b, 'status', 'start' )
-
-}
-
 =head2 get_nodes_openvz_status_ubc
 
 Get container user_beancounters.
@@ -1526,22 +1531,6 @@ vmid is an integer in pve-vmid format
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.Audit"]]
 
-=cut
-
-sub get_nodes_openvz_status_ubc {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for get_nodes_openvz_status_ubc()';
-    die 'node must be a scalar for get_nodes_openvz_status_ubc()' if ref $a;
-
-    my $b = shift or die 'No node for get_nodes_openvz_status_ubc()';
-    die 'node must be a scalar for get_nodes_openvz_status_ubc()' if ref $b;
-
-    return $self->post( $base, $a, 'openvz', $b, 'status', 'ubc' )
-
-}
-
 =head2 get_nodes_openvz_status_umount
 
 Unmounts container private area.
@@ -1554,34 +1543,23 @@ vmid is an integer in pve-vmid format
 
 Note: required permissions are ["perm","/vms/{vmid}",["VM.PowerMgmt"]]
 
-=cut
-
-sub get_nodes_openvz_status_umount {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No node for get_nodes_openvz_status_umount()';
-    die 'node must be a scalar for get_nodes_openvz_status_umount()' if ref $a;
-
-    my $b = shift or die 'No node for get_nodes_openvz_status_umount()';
-    die 'node must be a scalar for get_nodes_openvz_status_umount()' if ref $b;
-
-    return $self->post( $base, $a, 'openvz', $b, 'status', 'umount' )
-
-}
-
 =head1 SEE ALSO
 
   L<Net::Proxmox::VE>
 
-=head1 VERSION
+=head1 AUTHOR
 
-  VERSION 0.31
+Brendan Beveridge <brendan@nodeintegration.com.au>, Dean Hamstead <dean@bytefoundry.com.au>
 
-=head1 AUTHORS
+=head1 COPYRIGHT AND LICENSE
 
-  Dean Hamstead L<<dean@bytefoundry.com.au>>
+This software is copyright (c) 2016 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
+__END__
+
+# vim: softtabstop=2 tabstop=2 shiftwidth=2 ft=perl expandtab smarttab
