@@ -1,16 +1,114 @@
 #!/bin/false
-
-package Net::Proxmox::VE::Pools;
+# PODNAME: Net::Proxmox::VE::Pools
+# ABSTRACT: Presents a pool object
 
 use strict;
 use warnings;
-use base 'Exporter';
 
-=encoding utf8
+package Net::Proxmox::VE::Pools;
+$Net::Proxmox::VE::Pools::VERSION = '0.0094';
+use parent 'Exporter';
+
+
+our @EXPORT  = qw( pools );
+
+my $base = '/pools';
+
+
+sub pools {
+
+    my $self = shift or return;
+
+    return $self->get($base);
+
+}
+
+
+sub get_pool {
+
+    my $self = shift or return;
+
+    my $a = shift or die 'No poolid for get_pool()';
+    die 'poolid must be a scalar for get_pool()' if ref $a;
+
+    return $self->get( $base, $a );
+
+}
+
+
+sub create_pool {
+
+    my $self = shift or return;
+    my @p = @_;
+
+    die 'No arguments for create_pool()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for create_pool()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for create_pool()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->post( $base, \%args )
+
+}
+
+
+sub delete_pool {
+
+    my $self = shift or return;
+    my $a    = shift or die 'No argument given for delete_pool()';
+
+    return $self->delete( $base, $a );
+
+}
+
+
+sub update_pool {
+
+    my $self   = shift or return;
+    my $poolid = shift or die 'No poolid provided for update_pool()';
+    die 'poolid must be a scalar for update_pool()' if ref $poolid;
+    my @p = @_;
+
+    die 'No arguments for update_pool()' unless @p;
+    my %args;
+
+    if ( @p == 1 ) {
+        die 'Single argument not a hash for update_pool()'
+          unless ref $a eq 'HASH';
+        %args = %{ $p[0] };
+    }
+    else {
+        die 'Odd number of arguments for update_pool()'
+          if ( scalar @p % 2 != 0 );
+        %args = @p;
+    }
+
+    return $self->put( $base, $poolid, \%args )
+
+}
+
+
+1;
+
+=pod
+
+=encoding UTF-8
 
 =head1 NAME
 
-Net::Proxmox::VE::Pools
+Net::Proxmox::VE::Pools - Presents a pool object
+
+=head1 VERSION
+
+version 0.0094
 
 =head1 SYNOPSIS
 
@@ -42,29 +140,12 @@ straight to the server API. So garbage-in, garbage-out!
 
 =head1 METHODS
 
-=cut
-
-our $VERSION = 0.2;
-our @EXPORT  = qw( pools );
-
-my $base = '/pools';
-
 =head2 pools
 
 Gets a list of pools (aka the a Pool Index)
 
   @pools = $obj->pools();
 
-=cut
-
-sub pools {
-
-    my $self = shift or return;
-
-    return $self->get($base);
-
-}
-
 =head2 get_pool
 
 Gets a single pool's configuration details
@@ -73,19 +154,6 @@ Gets a single pool's configuration details
 
 poolid is a string in pve-poolid format
 
-=cut
-
-sub get_pool {
-
-    my $self = shift or return;
-
-    my $a = shift or die 'No poolid for get_pool()';
-    die 'poolid must be a scalar for get_pool()' if ref $a;
-
-    return $self->get( $base, $a );
-
-}
-
 =head2 create_pool
 
 Creates a new pool
@@ -107,31 +175,6 @@ String. This is a comment associated with the new pool, this is optional
 
 =back
 
-=cut
-
-sub create_pool {
-
-    my $self = shift or return;
-    my @p = @_;
-
-    die 'No arguments for create_pool()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for create_pool()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for create_pool()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->post( $base, \%args )
-
-}
-
 =head2 delete_pool
 
 Deletes a single pool
@@ -140,17 +183,6 @@ Deletes a single pool
 
 poolid is a string in pve-poolid format
 
-=cut
-
-sub delete_pool {
-
-    my $self = shift or return;
-    my $a    = shift or die 'No argument given for delete_pool()';
-
-    return $self->delete( $base, $a );
-
-}
-
 =head2 update_pool
 
 Updates (sets) a pool's data
@@ -182,45 +214,23 @@ String. List of virtual machines in pve-vmid-list format.
 
 =back
 
-=cut
-
-sub update_pool {
-
-    my $self   = shift or return;
-    my $poolid = shift or die 'No poolid provided for update_pool()';
-    die 'poolid must be a scalar for update_pool()' if ref $poolid;
-    my @p = @_;
-
-    die 'No arguments for update_pool()' unless @p;
-    my %args;
-
-    if ( @p == 1 ) {
-        die 'Single argument not a hash for update_pool()'
-          unless ref $a eq 'HASH';
-        %args = %{ $p[0] };
-    }
-    else {
-        die 'Odd number of arguments for update_pool()'
-          if ( scalar @p % 2 != 0 );
-        %args = @p;
-    }
-
-    return $self->put( $base, $poolid, \%args )
-
-}
-
 =head1 SEE ALSO
 
   L<Net::Proxmox::VE>
 
-=head1 VERSION
-
-  VERSION 0.2
-
 =head1 AUTHOR
 
- Dean Hamstead L<<dean@bytefoundry.com.au>>
+Brendan Beveridge <brendan@nodeintegration.com.au>, Dean Hamstead <dean@bytefoundry.com.au>
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2016 by Dean Hamstad.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
 
-1;
+__END__
+
+# vim: softtabstop=2 tabstop=2 shiftwidth=2 ft=perl expandtab smarttab
